@@ -642,6 +642,118 @@ namespace Model
      */
     inline CreateClientVpnEndpointRequest& AddTagSpecifications(TagSpecification&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetSecurityGroupIds() const{ return m_securityGroupIds; }
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline bool SecurityGroupIdsHasBeenSet() const { return m_securityGroupIdsHasBeenSet; }
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline void SetSecurityGroupIds(const Aws::Vector<Aws::String>& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds = value; }
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline void SetSecurityGroupIds(Aws::Vector<Aws::String>&& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds = std::move(value); }
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline CreateClientVpnEndpointRequest& WithSecurityGroupIds(const Aws::Vector<Aws::String>& value) { SetSecurityGroupIds(value); return *this;}
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline CreateClientVpnEndpointRequest& WithSecurityGroupIds(Aws::Vector<Aws::String>&& value) { SetSecurityGroupIds(std::move(value)); return *this;}
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline CreateClientVpnEndpointRequest& AddSecurityGroupIds(const Aws::String& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(value); return *this; }
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline CreateClientVpnEndpointRequest& AddSecurityGroupIds(Aws::String&& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The IDs of one or more security groups to apply to the target network. You
+     * must also specify the ID of the VPC that contains the security groups.</p>
+     */
+    inline CreateClientVpnEndpointRequest& AddSecurityGroupIds(const char* value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(value); return *this; }
+
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline const Aws::String& GetVpcId() const{ return m_vpcId; }
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline bool VpcIdHasBeenSet() const { return m_vpcIdHasBeenSet; }
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline void SetVpcId(const Aws::String& value) { m_vpcIdHasBeenSet = true; m_vpcId = value; }
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline void SetVpcId(Aws::String&& value) { m_vpcIdHasBeenSet = true; m_vpcId = std::move(value); }
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline void SetVpcId(const char* value) { m_vpcIdHasBeenSet = true; m_vpcId.assign(value); }
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline CreateClientVpnEndpointRequest& WithVpcId(const Aws::String& value) { SetVpcId(value); return *this;}
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline CreateClientVpnEndpointRequest& WithVpcId(Aws::String&& value) { SetVpcId(std::move(value)); return *this;}
+
+    /**
+     * <p>The ID of the VPC to associate with the Client VPN endpoint. If no security
+     * group IDs are specified in the request, the default security group for the VPC
+     * is applied.</p>
+     */
+    inline CreateClientVpnEndpointRequest& WithVpcId(const char* value) { SetVpcId(value); return *this;}
+
   private:
 
     Aws::String m_clientCidrBlock;
@@ -679,6 +791,12 @@ namespace Model
 
     Aws::Vector<TagSpecification> m_tagSpecifications;
     bool m_tagSpecificationsHasBeenSet;
+
+    Aws::Vector<Aws::String> m_securityGroupIds;
+    bool m_securityGroupIdsHasBeenSet;
+
+    Aws::String m_vpcId;
+    bool m_vpcIdHasBeenSet;
   };
 
 } // namespace Model
