@@ -48,6 +48,39 @@ namespace Model
 
   public:
 
+    /**
+     * <p>Checks whether you have the required permissions for the action, without
+     * actually making the request, and provides an error response. If you have the
+     * required permissions, the error response is <code>DryRunOperation</code>.
+     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
+     */
+    inline bool GetDryRun() const{ return m_dryRun; }
+
+    /**
+     * <p>Checks whether you have the required permissions for the action, without
+     * actually making the request, and provides an error response. If you have the
+     * required permissions, the error response is <code>DryRunOperation</code>.
+     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
+     */
+    inline bool DryRunHasBeenSet() const { return m_dryRunHasBeenSet; }
+
+    /**
+     * <p>Checks whether you have the required permissions for the action, without
+     * actually making the request, and provides an error response. If you have the
+     * required permissions, the error response is <code>DryRunOperation</code>.
+     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
+     */
+    inline void SetDryRun(bool value) { m_dryRunHasBeenSet = true; m_dryRun = value; }
+
+    /**
+     * <p>Checks whether you have the required permissions for the action, without
+     * actually making the request, and provides an error response. If you have the
+     * required permissions, the error response is <code>DryRunOperation</code>.
+     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
+     */
+    inline DescribeNatGatewaysRequest& WithDryRun(bool value) { SetDryRun(value); return *this;}
+
+
     /**
      * <p>One or more filters.</p> <ul> <li> <p> <code>nat-gateway-id</code> - The ID
      * of the NAT gateway.</p> </li> <li> <p> <code>state</code> - The state of the NAT
@@ -318,6 +351,9 @@ namespace Model
 
   private:
 
+    bool m_dryRun;
+    bool m_dryRunHasBeenSet;
+
     Aws::Vector<Filter> m_filter;
     bool m_filterHasBeenSet;
 
