@@ -20,6 +20,8 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/ec2/model/TrafficType.h>
 #include <aws/ec2/model/LogDestinationType.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/ec2/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -608,6 +610,47 @@ namespace Model
     inline FlowLog& WithLogFormat(const char* value) { SetLogFormat(value); return *this;}
 
 
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline FlowLog& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline FlowLog& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline FlowLog& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>The tags for the flow log.</p>
+     */
+    inline FlowLog& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
+
+
     /**
      * <p>The maximum interval of time, in seconds, during which a flow of packets is
      * captured and aggregated into a flow log record.</p> <p>When a network interface
@@ -690,6 +733,9 @@ namespace Model
     Aws::String m_logFormat;
     bool m_logFormatHasBeenSet;
 
+    Aws::Vector<Tag> m_tags;
+    bool m_tagsHasBeenSet;
+
     int m_maxAggregationInterval;
     bool m_maxAggregationIntervalHasBeenSet;
   };
