@@ -19,6 +19,7 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/ec2/model/PublicIpv4PoolRange.h>
+#include <aws/ec2/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -215,6 +216,104 @@ namespace Model
      */
     inline PublicIpv4Pool& WithTotalAvailableAddressCount(int value) { SetTotalAvailableAddressCount(value); return *this;}
 
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline const Aws::String& GetNetworkBorderGroup() const{ return m_networkBorderGroup; }
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline bool NetworkBorderGroupHasBeenSet() const { return m_networkBorderGroupHasBeenSet; }
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline void SetNetworkBorderGroup(const Aws::String& value) { m_networkBorderGroupHasBeenSet = true; m_networkBorderGroup = value; }
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline void SetNetworkBorderGroup(Aws::String&& value) { m_networkBorderGroupHasBeenSet = true; m_networkBorderGroup = std::move(value); }
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline void SetNetworkBorderGroup(const char* value) { m_networkBorderGroupHasBeenSet = true; m_networkBorderGroup.assign(value); }
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline PublicIpv4Pool& WithNetworkBorderGroup(const Aws::String& value) { SetNetworkBorderGroup(value); return *this;}
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline PublicIpv4Pool& WithNetworkBorderGroup(Aws::String&& value) { SetNetworkBorderGroup(std::move(value)); return *this;}
+
+    /**
+     * <p>The name of the location from which the address pool is advertised. A network
+     * border group is a unique set of Availability Zones or Local Zones from where AWS
+     * advertises public IP addresses.</p>
+     */
+    inline PublicIpv4Pool& WithNetworkBorderGroup(const char* value) { SetNetworkBorderGroup(value); return *this;}
+
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline PublicIpv4Pool& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline PublicIpv4Pool& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline PublicIpv4Pool& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>Any tags for the address pool.</p>
+     */
+    inline PublicIpv4Pool& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_poolId;
@@ -231,6 +330,12 @@ namespace Model
 
     int m_totalAvailableAddressCount;
     bool m_totalAvailableAddressCountHasBeenSet;
+
+    Aws::String m_networkBorderGroup;
+    bool m_networkBorderGroupHasBeenSet;
+
+    Aws::Vector<Tag> m_tags;
+    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
