@@ -27,6 +27,7 @@
 #include <aws/ec2/model/LoadBalancersConfig.h>
 #include <aws/ec2/model/SpotFleetLaunchSpecification.h>
 #include <aws/ec2/model/LaunchTemplateConfig.h>
+#include <aws/ec2/model/TagSpecification.h>
 #include <utility>
 
 namespace Aws
@@ -373,8 +374,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline const Aws::String& GetIamFleetRole() const{ return m_iamFleetRole; }
 
@@ -385,8 +388,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline bool IamFleetRoleHasBeenSet() const { return m_iamFleetRoleHasBeenSet; }
 
@@ -397,8 +402,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline void SetIamFleetRole(const Aws::String& value) { m_iamFleetRoleHasBeenSet = true; m_iamFleetRole = value; }
 
@@ -409,8 +416,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline void SetIamFleetRole(Aws::String&& value) { m_iamFleetRoleHasBeenSet = true; m_iamFleetRole = std::move(value); }
 
@@ -421,8 +430,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline void SetIamFleetRole(const char* value) { m_iamFleetRoleHasBeenSet = true; m_iamFleetRole.assign(value); }
 
@@ -433,8 +444,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline SpotFleetRequestConfigData& WithIamFleetRole(const Aws::String& value) { SetIamFleetRole(value); return *this;}
 
@@ -445,8 +458,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline SpotFleetRequestConfigData& WithIamFleetRole(Aws::String&& value) { SetIamFleetRole(std::move(value)); return *this;}
 
@@ -457,8 +472,10 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites">Spot
      * Fleet Prerequisites</a> in the <i>Amazon EC2 User Guide for Linux Instances</i>.
      * Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot
-     * Fleet request using <a>CancelSpotFleetRequests</a> or when the Spot Fleet
-     * request expires, if you set <code>TerminateInstancesWithExpiration</code>.</p>
+     * Fleet request using <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests">CancelSpotFleetRequests</a>
+     * or when the Spot Fleet request expires, if you set
+     * <code>TerminateInstancesWithExpiration</code>.</p>
      */
     inline SpotFleetRequestConfigData& WithIamFleetRole(const char* value) { SetIamFleetRole(value); return *this;}
 
@@ -1273,6 +1290,143 @@ namespace Model
      */
     inline SpotFleetRequestConfigData& WithInstancePoolsToUseCount(int value) { SetInstancePoolsToUseCount(value); return *this;}
 
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline const Aws::Vector<TagSpecification>& GetTagSpecifications() const{ return m_tagSpecifications; }
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline bool TagSpecificationsHasBeenSet() const { return m_tagSpecificationsHasBeenSet; }
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline void SetTagSpecifications(const Aws::Vector<TagSpecification>& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications = value; }
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline void SetTagSpecifications(Aws::Vector<TagSpecification>&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications = std::move(value); }
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline SpotFleetRequestConfigData& WithTagSpecifications(const Aws::Vector<TagSpecification>& value) { SetTagSpecifications(value); return *this;}
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline SpotFleetRequestConfigData& WithTagSpecifications(Aws::Vector<TagSpecification>&& value) { SetTagSpecifications(std::move(value)); return *this;}
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline SpotFleetRequestConfigData& AddTagSpecifications(const TagSpecification& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(value); return *this; }
+
+    /**
+     * <p>The key-value pair for tagging the Spot Fleet request on creation. The value
+     * for <code>ResourceType</code> must be <code>spot-fleet-request</code>, otherwise
+     * the Spot Fleet request fails. To tag instances at launch, specify the tags in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template">launch
+     * template</a> (valid only if you use <code>LaunchTemplateConfigs</code>) or in
+     * the <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html">
+     * <code>SpotFleetTagSpecification</code> </a> (valid only if you use
+     * <code>LaunchSpecifications</code>). For information about tagging after launch,
+     * see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources">Tagging
+     * Your Resources</a>.</p>
+     */
+    inline SpotFleetRequestConfigData& AddTagSpecifications(TagSpecification&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(std::move(value)); return *this; }
+
   private:
 
     AllocationStrategy m_allocationStrategy;
@@ -1340,6 +1494,9 @@ namespace Model
 
     int m_instancePoolsToUseCount;
     bool m_instancePoolsToUseCountHasBeenSet;
+
+    Aws::Vector<TagSpecification> m_tagSpecifications;
+    bool m_tagSpecificationsHasBeenSet;
   };
 
 } // namespace Model
